CallCommandWsMsg class

Message for calling commands and waiting for responses.

Request/response pattern for commands that need return values.

Implemented types

Constructors

CallCommandWsMsg(String actorName, EntityId to, RemoteCommand cmd)
Creates a call command message.
CallCommandWsMsg.fromJson(Map<String, dynamic> json)
factory

Properties

actorName String
Name of the target entity or service type.
final
cmd Map<String, dynamic>
JSON of the command which is being called.
final
hashCode int
The hash code for this object.
no setterinherited
messageType String
Type identifier for this message used in JSON serialization.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to String
ID of the specific entity instance to call.
final
type String
Type of the command which is being called.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the message to JSON for network transmission.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited