QueryResultWsMsg class

Message containing the results of a query request.

Sent by server in response to QueryWsMsg with the requested view data.

Implemented types
Annotations
  • @JsonSerializable.new()

Constructors

QueryResultWsMsg({required QueryResult result})
Creates a query result message.
QueryResultWsMsg.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
messageType String
Type identifier for this message used in JSON serialization.
no setteroverride
result QueryResult
The query results containing view data.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the message to JSON for network transmission.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited