ReplyClient.none constructor
ReplyClient.none()
Creates empty reply client when no client reply is needed.
Implementation
ReplyClient.none() : serverId = '', sessionId = '', callId = '';
Creates empty reply client when no client reply is needed.
ReplyClient.none() : serverId = '', sessionId = '', callId = '';