CompositeId class
Identifier composed of two entity IDs for representing relationships.
Used when you need to create a unique identifier from two entity IDs, such as for many-to-many relationships or composite keys.
Constructors
- CompositeId(EntityId id1, EntityId id2)
- Creates a composite ID from two entity identifiers.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → EntityId
-
Returns the composite identifier as a single string.
no setter
- id1 → EntityId
-
First component of the composite identifier.
final
- id2 → EntityId
-
Second component of the composite identifier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → EntityId -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited