EntityStateInitProjector<E extends RemoteEvent> typedef
EntityStateInitProjector<E extends RemoteEvent> =
EntityState Function(E event)
Function that creates initial entity state from an init event.
Called when an entity is first created to establish its initial state from the data contained in the initialization event.
Implementation
typedef EntityStateInitProjector<E extends RemoteEvent> =
EntityState Function(E event);