RefQueryResult class
Query result for reference views.
Contains an entity reference with optional nested query results and attributes associated with the reference.
- Inheritance
-
- Object
- ViewQueryResult
- RefQueryResult
Constructors
-
RefQueryResult(dynamic value, Map<
String, dynamic> attrs, String changeId, QueryResult? query) - Creates a reference query result with attributes and nested query.
-
RefQueryResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
attrs
→ Map<
String, dynamic> -
Attributes associated with this reference.
final
- changeId → String
-
Change ID indicating the version of this result.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- query → QueryResult?
-
Results from querying the referenced entity (if requested).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → EntityId?
-
The referenced entity ID, or null if no reference is set.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the result to JSON for network transmission.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited